This filter primitive produces an image which contains the specular
reflection part of the lighting calculation. Such a map is intended to
be combined with a texture using the add term of the arithmetic method
in feComposite. Multiple light sources can be simulated
by adding several of these light maps before applying it to the
texture image.
feSpecularLighting(input = NA,
surfaceScale = 1, specularConstant = 1,
specularExponent = 1, kernelUnitLength = NA,
col = "white", lightSource = NULL, ...)filterInputs.kd in the Phong lighting model. Must be non-negative.dx value. The second number is the
dy value. If the dy value is not specified, it
defaults to the same value as dx. Indicates the intended
distance in current filter ulightSource.feDistantLight, fePointLight, or
feSpotLightfe.fe.specular.lighting object.filterEffect fe,
feDistantLight, fePointLight,
feSpotLight.